View source: R/summary.decomposition.R
| summary.decomposition | R Documentation |
decomposition object.Prints and returns a summary for a decomposition object.
## S3 method for class 'decomposition'
summary(object, digits = getOption("digits"), addcoefs = FALSE, ...)
object |
Result of a decomposition analysis, of class |
digits |
Number of digits, defaults to R |
addcoefs |
Whether or not to add coefficients (defaults to |
... |
Additional parameters, currently unused |
A data frame frame with columns for the absolute and relative contribution, elasticity, concentration index including confidence intervals,
and whether correction was applied. If specified using addcoefs, the coefficients are included as the first column.
data(housing)
# Linear regression & decompose
fit.lm <- lm(bmi ~ sex + tenure + place + age,data = housing)
contrib.lm <- contribution(fit.lm, housing$income)
# print
print(contrib.lm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.