Learn R Programming

rineq (version 0.3.0)

summary.hci: Prints the a summary of the concentration index object hci

Description

Prints the a summary of the concentration index object hci

Usage

# S3 method for hci
summary(object, ...)

Value

No returns value. Directly prints to the standard output connection.

Arguments

object

Object of type hci

...

Currently unused

Examples

Run this code
data(housing)
ci.bmi <- ci(ineqvar = housing$income, outcome = housing$bmi, method = "direct")
summary(ci.bmi)

Run the code above in your browser using DataLab